@@ -13,7 +13,7 @@ def create_footprint(
     footprint_lib,
     output_dir,
     model_base_variable,
-    skip_existing
+    skip_existing,
 ):
     logging.info("creating footprint ...")
 
@@ -23,7 +23,9 @@ def create_footprint(
 
     if skip_existing:
         # check if footprint already exists:
-        if os.path.isfile(os.path.join(output_dir, footprint_lib, footprint_name + ".kicad_mod")):
+        if os.path.isfile(
+            os.path.join(output_dir, footprint_lib, footprint_name + ".kicad_mod")
+        ):
             logging.info(f"Footprint {footprint_name} already exists, skipping.")
             return f"{footprint_lib}:{footprint_name}", datasheet_link
 
@@ -33,7 +35,9 @@ def create_footprint(
     kicad_mod.setTags(f"{footprint_name} footprint")
 
     class footprint_info:
-        def __init__(self, footprint_name, output_dir, footprint_lib, model_base_variable):
+        def __init__(
+            self, footprint_name, output_dir, footprint_lib, model_base_variable
+        ):
             self.max_X, self.max_Y, self.min_X, self.min_Y = (
                 -10000,
                 -10000,
@@ -49,7 +53,7 @@ def create_footprint(
         footprint_name=footprint_name,
         output_dir=output_dir,
         footprint_lib=footprint_lib,
-        model_base_variable=model_base_variable
+        model_base_variable=model_base_variable,
     )
 
     # for each line in data : use the appropriate handler
